Transformations based on equivalence classes
--------------------------------------------

**Header:** ``mockturtle/algorithms/equivalence_classes.hpp``


Algorithms
~~~~~~~~~~

.. doxygenfunction:: mockturtle::apply_spectral_transformations
.. doxygenfunction:: mockturtle::apply_npn_transformations
